@@ -28,4 +28,24 @@ class Dynabuffers:
             return InputStream(obj.decode("utf-8"))
         if isinstance(obj, bytearray):
             return InputStream(obj.decode("utf-8"))
+        if isinstance(obj, DynabuffersResource):
+            return obj.get_content_stream()
         raise ValueError(str(obj) + " cannot be converted to input stream")
+
+
+class DynabuffersResource:
+
+    def __init__(self):
+        self.builder = ""
+
+    def append(self, schema):
+        if isinstance(schema, str):
+            self.builder += str(schema)
+        if isinstance(schema, bytes):
+            self.builder += schema.decode("utf-8")
+        if isinstance(schema, bytearray):
+            self.builder += schema.decode("utf-8")
+        raise ValueError(str(schema) + " cannot be appended to resource")
+
+    def get_content_stream(self):
+        return InputStream(self.builder)
